Mockerena
=========
[![Build Status](https://travis-ci.org/jlane9/mockerena.svg?branch=master)](https://travis-ci.org/jlane9/mockerena)
[![Maintainability](https://api.codeclimate.com/v1/badges/e2ba8628f5a30a4a1fc8/maintainability)](https://codeclimate.com/github/jlane9/mockerena/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/e2ba8628f5a30a4a1fc8/test_coverage)](https://codeclimate.com/github/jlane9/mockerena/test_coverage)
[![PyPI version](https://badge.fury.io/py/mockerena.svg)](https://badge.fury.io/py/mockerena)
[![Python version](https://img.shields.io/pypi/pyversions/mockerena.svg)](https://pypi.python.org/pypi/mockerena)
[![License](https://img.shields.io/pypi/l/mockerena.svg)](https://pypi.python.org/pypi/mockerena)
[![Status](https://img.shields.io/pypi/status/mockerena.svg)](https://pypi.python.org/pypi/mockerena)
[![Documentation Status](https://readthedocs.org/projects/mockerena/badge/?version=latest)](https://mockerena.readthedocs.io/en/latest/?badge=latest)
[![Requirements Status](https://requires.io/github/jlane9/mockerena/requirements.svg?branch=master)](https://requires.io/github/jlane9/mockerena/requirements/?branch=master)

Mockerena allows anyone to mock data files through customized json
schemas and provides routes for external systems to retrieve from it.

## Table of Contents

### [Getting Started](https://github.com/FanThreeSixty/mockerena/blob/master/docs/install.rst)

### [Development](https://github.com/FanThreeSixty/mockerena/blob/master/docs/development.rst)

### [Routes](https://github.com/FanThreeSixty/mockerena/blob/master/docs/routes.rst)
